@@ -1,7 +1,7 @@
 /*
  *  newalarmaction.h  -  menu action to select a new alarm type
  *  Program:  kalarm
- *  Copyright © 2007-2009,2011 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2007-2009,2011,2018 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,19 +25,20 @@
 #include <kactionmenu.h>
 #include <QMap>
 #include <QAction>
+class KActionCollection;
 class TemplateMenuAction;
 
 class NewAlarmAction : public KActionMenu
 {
         Q_OBJECT
     public:
-        NewAlarmAction(bool templates, const QString& label, QObject* parent);
+        NewAlarmAction(bool templates, const QString& label, QObject* parent, KActionCollection* collection = nullptr);
         virtual ~NewAlarmAction() {}
-        QAction* displayAlarmAction() const  { return mDisplayAction; }
-        QAction* commandAlarmAction() const  { return mCommandAction; }
-        QAction* emailAlarmAction() const    { return mEmailAction; }
-        QAction* audioAlarmAction() const    { return mAudioAction; }
-        TemplateMenuAction* fromTemplateAlarmAction() const  { return mTemplateAction; }
+        QAction* displayAlarmAction(const QString& name);
+        QAction* commandAlarmAction(const QString& name);
+        QAction* emailAlarmAction(const QString& name);
+        QAction* audioAlarmAction(const QString& name);
+        TemplateMenuAction* fromTemplateAlarmAction(const QString& name);
 
     Q_SIGNALS:
         void   selected(EditAlarmDlg::Type);
@@ -53,6 +54,7 @@ class NewAlarmAction : public KActionMenu
         QAction*            mEmailAction;
         QAction*            mAudioAction;
         TemplateMenuAction* mTemplateAction;   // New From Template action, for non-template menu only
+        KActionCollection*  mActionCollection;
         QMap<QAction*, EditAlarmDlg::Type> mTypes;
 };
 
